[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] x86: Clean up shadow_page_info after page_info changes.



# HG changeset patch
# User Keir Fraser <keir.fraser@xxxxxxxxxx>
# Date 1232988758 0
# Node ID 728d1892f0e24c2531df2d61a2d95177400ceb17
# Parent  90909b81b3b9cf9b303e2bc457580603da3ac7fd
x86: Clean up shadow_page_info after page_info changes.
Signed-off-by: Keir Fraser <keir.fraser@xxxxxxxxxx>
---
 xen/arch/x86/mm/shadow/private.h |   16 +++++-----------
 1 files changed, 5 insertions(+), 11 deletions(-)

diff -r 90909b81b3b9 -r 728d1892f0e2 xen/arch/x86/mm/shadow/private.h
--- a/xen/arch/x86/mm/shadow/private.h  Mon Jan 26 16:34:51 2009 +0000
+++ b/xen/arch/x86/mm/shadow/private.h  Mon Jan 26 16:52:38 2009 +0000
@@ -244,16 +244,10 @@ struct shadow_page_info
                 u32 tlbflush_timestamp;
             };
             struct {
-                unsigned int type:5;   /* What kind of shadow is this? */
-                unsigned int pinned:1; /* Is the shadow pinned? */
-                unsigned int count:26; /* Reference count */
-#ifdef __x86_64__
-                u32 pad;
-                u64 mbz;               /* Must be zero: this is where the
-                                        * owner field lives in page_info */
-#else
-                u32 mbz;
-#endif
+                unsigned long mbz;     /* Must be zero: count_info is here. */
+                unsigned long type:5;   /* What kind of shadow is this? */
+                unsigned long pinned:1; /* Is the shadow pinned? */
+                unsigned long count:26; /* Reference count */
             } __attribute__((packed));
             union {
                 /* For unused shadow pages, a list of pages of this order; for 
@@ -277,7 +271,7 @@ static inline void shadow_check_page_str
     BUILD_BUG_ON(sizeof (struct shadow_page_info) !=
                  sizeof (struct page_info));
     BUILD_BUG_ON(offsetof(struct shadow_page_info, mbz) !=
-                 offsetof(struct page_info, u.inuse._domain));
+                 offsetof(struct page_info, count_info));
 };
 
 /* Shadow type codes */

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.